diff --git a/bridges/bin/runtime-common/src/messages_api.rs b/bridges/bin/runtime-common/src/messages_api.rs
index ccf1c754041ed84dc302f0660fdd5bde8dc8d533..7fbdeb366124778b36c77725be8ca8778020be1b 100644
--- a/bridges/bin/runtime-common/src/messages_api.rs
+++ b/bridges/bin/runtime-common/src/messages_api.rs
@@ -14,7 +14,7 @@
 // You should have received a copy of the GNU General Public License
 // along with Parity Bridges Common.  If not, see <http://www.gnu.org/licenses/>.
 
-//! Helpers for implementing various message-related runtime API mthods.
+//! Helpers for implementing various message-related runtime API methods.
 
 use bp_messages::{
 	InboundMessageDetails, LaneId, MessageNonce, MessagePayload, OutboundMessageDetails,
diff --git a/bridges/bin/runtime-common/src/messages_xcm_extension.rs b/bridges/bin/runtime-common/src/messages_xcm_extension.rs
index e3da6155f08a198d5469adbfc64e40213eddf8eb..46ed4da0d85481fcc7223740084945924f9c710f 100644
--- a/bridges/bin/runtime-common/src/messages_xcm_extension.rs
+++ b/bridges/bin/runtime-common/src/messages_xcm_extension.rs
@@ -248,7 +248,7 @@ impl<H: XcmBlobHauler> LocalXcmQueueManager<H> {
 		sender_and_lane: &SenderAndLane,
 		enqueued_messages: MessageNonce,
 	) {
-		// skip if we dont want to handle congestion
+		// skip if we don't want to handle congestion
 		if !H::supports_congestion_detection() {
 			return
 		}
diff --git a/bridges/bin/runtime-common/src/mock.rs b/bridges/bin/runtime-common/src/mock.rs
index deee4524e8586d45c01f08126e84b9c619cfeba2..8c4cb2233e17c7ff0f6aa05f45483db07ef2b707 100644
--- a/bridges/bin/runtime-common/src/mock.rs
+++ b/bridges/bin/runtime-common/src/mock.rs
@@ -379,7 +379,7 @@ impl Chain for BridgedUnderlyingChain {
 impl ChainWithGrandpa for BridgedUnderlyingChain {
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = "";
 	const MAX_AUTHORITIES_COUNT: u32 = 16;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 = 8;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 = 8;
 	const MAX_MANDATORY_HEADER_SIZE: u32 = 256;
 	const AVERAGE_HEADER_SIZE: u32 = 64;
 }
diff --git a/bridges/bin/runtime-common/src/priority_calculator.rs b/bridges/bin/runtime-common/src/priority_calculator.rs
index c2737128e3422dd72ca3b49d66151268d719e0bc..5035553f508dfea94a0cb5ddf9b916dd7d9b4ea5 100644
--- a/bridges/bin/runtime-common/src/priority_calculator.rs
+++ b/bridges/bin/runtime-common/src/priority_calculator.rs
@@ -163,7 +163,7 @@ mod integrity_tests {
 	{
 		// just an estimation of extra transaction bytes that are added to every transaction
 		// (including signature, signed extensions extra and etc + in our case it includes
-		// all call arguments extept the proof itself)
+		// all call arguments except the proof itself)
 		let base_tx_size = 512;
 		// let's say we are relaying similar small messages and for every message we add more trie
 		// nodes to the proof (x0.5 because we expect some nodes to be reused)
diff --git a/bridges/bin/runtime-common/src/refund_relayer_extension.rs b/bridges/bin/runtime-common/src/refund_relayer_extension.rs
index 8e901d72821fe1dfb749f4227c2875f1d807fccc..455392a0a277f3520cd7f58150f12e7420d36014 100644
--- a/bridges/bin/runtime-common/src/refund_relayer_extension.rs
+++ b/bridges/bin/runtime-common/src/refund_relayer_extension.rs
@@ -1538,7 +1538,7 @@ mod tests {
 	}
 
 	#[test]
-	fn validate_boosts_priority_of_message_delivery_transactons() {
+	fn validate_boosts_priority_of_message_delivery_transactions() {
 		run_test(|| {
 			initialize_environment(100, 100, 100);
 
@@ -1568,7 +1568,7 @@ mod tests {
 	}
 
 	#[test]
-	fn validate_does_not_boost_priority_of_message_delivery_transactons_with_too_many_messages() {
+	fn validate_does_not_boost_priority_of_message_delivery_transactions_with_too_many_messages() {
 		run_test(|| {
 			initialize_environment(100, 100, 100);
 
diff --git a/bridges/chains/chain-kusama/src/lib.rs b/bridges/chains/chain-kusama/src/lib.rs
index e3b4d0520f61c858b54d78dfa4a45f57bac411fb..a81004afe8127b556211d0207d2bc1f9ecc02955 100644
--- a/bridges/chains/chain-kusama/src/lib.rs
+++ b/bridges/chains/chain-kusama/src/lib.rs
@@ -53,8 +53,8 @@ impl Chain for Kusama {
 impl ChainWithGrandpa for Kusama {
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = WITH_KUSAMA_GRANDPA_PALLET_NAME;
 	const MAX_AUTHORITIES_COUNT: u32 = MAX_AUTHORITIES_COUNT;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 =
-		REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 =
+		REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY;
 	const MAX_MANDATORY_HEADER_SIZE: u32 = MAX_MANDATORY_HEADER_SIZE;
 	const AVERAGE_HEADER_SIZE: u32 = AVERAGE_HEADER_SIZE;
 }
diff --git a/bridges/chains/chain-polkadot-bulletin/src/lib.rs b/bridges/chains/chain-polkadot-bulletin/src/lib.rs
index f2eebf9312470a42e1d3a1c7d67ab8b7a38af189..f3d300567f2b4f92cec272e0929a3c53d718c823 100644
--- a/bridges/chains/chain-polkadot-bulletin/src/lib.rs
+++ b/bridges/chains/chain-polkadot-bulletin/src/lib.rs
@@ -43,7 +43,7 @@ use sp_runtime::{traits::DispatchInfoOf, transaction_validity::TransactionValidi
 pub use bp_polkadot_core::{
 	AccountAddress, AccountId, Balance, Block, BlockNumber, Hash, Hasher, Header, Nonce, Signature,
 	SignedBlock, UncheckedExtrinsic, AVERAGE_HEADER_SIZE, EXTRA_STORAGE_PROOF_SIZE,
-	MAX_MANDATORY_HEADER_SIZE, REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY,
+	MAX_MANDATORY_HEADER_SIZE, REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY,
 };
 
 /// Maximal number of GRANDPA authorities at Polkadot Bulletin chain.
@@ -62,7 +62,7 @@ const NORMAL_DISPATCH_RATIO: Perbill = Perbill::from_percent(90);
 
 // Re following constants - we are using the same values at Cumulus parachains. They are limited
 // by the maximal transaction weight/size. Since block limits at Bulletin Chain are larger than
-// at the Cumulus Bridgeg Hubs, we could reuse the same values.
+// at the Cumulus Bridge Hubs, we could reuse the same values.
 
 /// Maximal number of unrewarded relayer entries at inbound lane for Cumulus-based parachains.
 pub const MAX_UNREWARDED_RELAYERS_IN_CONFIRMATION_TX: MessageNonce = 1024;
@@ -207,8 +207,8 @@ impl Chain for PolkadotBulletin {
 impl ChainWithGrandpa for PolkadotBulletin {
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = WITH_POLKADOT_BULLETIN_GRANDPA_PALLET_NAME;
 	const MAX_AUTHORITIES_COUNT: u32 = MAX_AUTHORITIES_COUNT;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 =
-		REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 =
+		REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY;
 	const MAX_MANDATORY_HEADER_SIZE: u32 = MAX_MANDATORY_HEADER_SIZE;
 	const AVERAGE_HEADER_SIZE: u32 = AVERAGE_HEADER_SIZE;
 }
diff --git a/bridges/chains/chain-polkadot/src/lib.rs b/bridges/chains/chain-polkadot/src/lib.rs
index fc5e10308a8e33463a74c041f157daaef09cc9c8..00d35783a9b61844bab7701fdb60711125447ca3 100644
--- a/bridges/chains/chain-polkadot/src/lib.rs
+++ b/bridges/chains/chain-polkadot/src/lib.rs
@@ -55,8 +55,8 @@ impl Chain for Polkadot {
 impl ChainWithGrandpa for Polkadot {
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = WITH_POLKADOT_GRANDPA_PALLET_NAME;
 	const MAX_AUTHORITIES_COUNT: u32 = MAX_AUTHORITIES_COUNT;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 =
-		REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 =
+		REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY;
 	const MAX_MANDATORY_HEADER_SIZE: u32 = MAX_MANDATORY_HEADER_SIZE;
 	const AVERAGE_HEADER_SIZE: u32 = AVERAGE_HEADER_SIZE;
 }
diff --git a/bridges/chains/chain-rococo/src/lib.rs b/bridges/chains/chain-rococo/src/lib.rs
index f1b256f0f090f048cc8db3a16c112ed8b938f6ce..2385dd2cbb250181ce5f46aef9f1e76f8fd010d2 100644
--- a/bridges/chains/chain-rococo/src/lib.rs
+++ b/bridges/chains/chain-rococo/src/lib.rs
@@ -53,8 +53,8 @@ impl Chain for Rococo {
 impl ChainWithGrandpa for Rococo {
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = WITH_ROCOCO_GRANDPA_PALLET_NAME;
 	const MAX_AUTHORITIES_COUNT: u32 = MAX_AUTHORITIES_COUNT;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 =
-		REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 =
+		REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY;
 	const MAX_MANDATORY_HEADER_SIZE: u32 = MAX_MANDATORY_HEADER_SIZE;
 	const AVERAGE_HEADER_SIZE: u32 = AVERAGE_HEADER_SIZE;
 }
diff --git a/bridges/chains/chain-westend/src/lib.rs b/bridges/chains/chain-westend/src/lib.rs
index f03fd2160a700eb3817a6feb629e9d366cc366aa..b344b7f4bf93392c08502446513a9ae39296b512 100644
--- a/bridges/chains/chain-westend/src/lib.rs
+++ b/bridges/chains/chain-westend/src/lib.rs
@@ -53,8 +53,8 @@ impl Chain for Westend {
 impl ChainWithGrandpa for Westend {
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = WITH_WESTEND_GRANDPA_PALLET_NAME;
 	const MAX_AUTHORITIES_COUNT: u32 = MAX_AUTHORITIES_COUNT;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 =
-		REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 =
+		REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY;
 	const MAX_MANDATORY_HEADER_SIZE: u32 = MAX_MANDATORY_HEADER_SIZE;
 	const AVERAGE_HEADER_SIZE: u32 = AVERAGE_HEADER_SIZE;
 }
diff --git a/bridges/modules/grandpa/README.md b/bridges/modules/grandpa/README.md
index 992bd2cc47228249310c56747416b07be6e1e287..4a3099b8afc654bfced296aaa0ead4a5d113eb7f 100644
--- a/bridges/modules/grandpa/README.md
+++ b/bridges/modules/grandpa/README.md
@@ -10,7 +10,7 @@ It is used by the parachains light client (bridge parachains pallet) and by mess
 ## A Brief Introduction into GRANDPA Finality
 
 You can find detailed information on GRANDPA, by exploring its [repository](https://github.com/paritytech/finality-grandpa).
-Here is the minimal reqiuired GRANDPA information to understand how pallet works.
+Here is the minimal required GRANDPA information to understand how pallet works.
 
 Any Substrate chain may use different block authorship algorithms (like BABE or Aura) to determine block producers and
 generate blocks. This has nothing common with finality, though - the task of block authorship is to coordinate
diff --git a/bridges/modules/grandpa/src/lib.rs b/bridges/modules/grandpa/src/lib.rs
index ce2c47da954fa46efc4c70e9608864735fa16277..9e095651ef81da1e5418d7532ae56ae0fb8ef564 100644
--- a/bridges/modules/grandpa/src/lib.rs
+++ b/bridges/modules/grandpa/src/lib.rs
@@ -935,7 +935,7 @@ mod tests {
 	}
 
 	#[test]
-	fn succesfully_imports_header_with_valid_finality() {
+	fn successfully_imports_header_with_valid_finality() {
 		run_test(|| {
 			initialize_substrate_bridge();
 
@@ -1192,7 +1192,7 @@ mod tests {
 			header.digest = change_log(0);
 			let justification = make_justification_for_header(JustificationGeneratorParams {
 				header: header.clone(),
-				ancestors: TestBridgedChain::REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY + 1,
+				ancestors: TestBridgedChain::REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY + 1,
 				..Default::default()
 			});
 
diff --git a/bridges/modules/grandpa/src/mock.rs b/bridges/modules/grandpa/src/mock.rs
index 4318d663a2e17fe80199830d443f5b6a85fae441..e689e520c92ffcb230a83f7a728722a688729417 100644
--- a/bridges/modules/grandpa/src/mock.rs
+++ b/bridges/modules/grandpa/src/mock.rs
@@ -87,7 +87,7 @@ impl Chain for TestBridgedChain {
 impl ChainWithGrandpa for TestBridgedChain {
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = "";
 	const MAX_AUTHORITIES_COUNT: u32 = MAX_BRIDGED_AUTHORITIES;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 = 8;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 = 8;
 	const MAX_MANDATORY_HEADER_SIZE: u32 = 256;
 	const AVERAGE_HEADER_SIZE: u32 = 64;
 }
diff --git a/bridges/modules/messages/src/inbound_lane.rs b/bridges/modules/messages/src/inbound_lane.rs
index 966ec939e70e22e830ee30157d2d7da74d59733c..da1698e6e0370f9f84ca8dd53bc1ebc99f696017 100644
--- a/bridges/modules/messages/src/inbound_lane.rs
+++ b/bridges/modules/messages/src/inbound_lane.rs
@@ -21,7 +21,7 @@ use crate::Config;
 use bp_messages::{
 	target_chain::{DispatchMessage, DispatchMessageData, MessageDispatch},
 	DeliveredMessages, InboundLaneData, LaneId, MessageKey, MessageNonce, OutboundLaneData,
-	ReceivalResult, UnrewardedRelayer,
+	ReceptionResult, UnrewardedRelayer,
 };
 use codec::{Decode, Encode, EncodeLike, MaxEncodedLen};
 use frame_support::traits::Get;
@@ -170,21 +170,21 @@ impl<S: InboundLaneStorage> InboundLane<S> {
 		relayer_at_bridged_chain: &S::Relayer,
 		nonce: MessageNonce,
 		message_data: DispatchMessageData<Dispatch::DispatchPayload>,
-	) -> ReceivalResult<Dispatch::DispatchLevelResult> {
+	) -> ReceptionResult<Dispatch::DispatchLevelResult> {
 		let mut data = self.storage.get_or_init_data();
 		if Some(nonce) != data.last_delivered_nonce().checked_add(1) {
-			return ReceivalResult::InvalidNonce
+			return ReceptionResult::InvalidNonce
 		}
 
 		// if there are more unrewarded relayer entries than we may accept, reject this message
 		if data.relayers.len() as MessageNonce >= self.storage.max_unrewarded_relayer_entries() {
-			return ReceivalResult::TooManyUnrewardedRelayers
+			return ReceptionResult::TooManyUnrewardedRelayers
 		}
 
 		// if there are more unconfirmed messages than we may accept, reject this message
 		let unconfirmed_messages_count = nonce.saturating_sub(data.last_confirmed_nonce);
 		if unconfirmed_messages_count > self.storage.max_unconfirmed_messages() {
-			return ReceivalResult::TooManyUnconfirmedMessages
+			return ReceptionResult::TooManyUnconfirmedMessages
 		}
 
 		// then, dispatch message
@@ -207,7 +207,7 @@ impl<S: InboundLaneStorage> InboundLane<S> {
 		};
 		self.storage.set_data(data);
 
-		ReceivalResult::Dispatched(dispatch_result)
+		ReceptionResult::Dispatched(dispatch_result)
 	}
 }
 
@@ -235,7 +235,7 @@ mod tests {
 				nonce,
 				inbound_message_data(REGULAR_PAYLOAD)
 			),
-			ReceivalResult::Dispatched(dispatch_result(0))
+			ReceptionResult::Dispatched(dispatch_result(0))
 		);
 	}
 
@@ -362,7 +362,7 @@ mod tests {
 					10,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::InvalidNonce
+				ReceptionResult::InvalidNonce
 			);
 			assert_eq!(lane.storage.get_or_init_data().last_delivered_nonce(), 0);
 		});
@@ -381,7 +381,7 @@ mod tests {
 						current_nonce,
 						inbound_message_data(REGULAR_PAYLOAD)
 					),
-					ReceivalResult::Dispatched(dispatch_result(0))
+					ReceptionResult::Dispatched(dispatch_result(0))
 				);
 			}
 			// Fails to dispatch new message from different than latest relayer.
@@ -391,7 +391,7 @@ mod tests {
 					max_nonce + 1,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::TooManyUnrewardedRelayers,
+				ReceptionResult::TooManyUnrewardedRelayers,
 			);
 			// Fails to dispatch new messages from latest relayer. Prevents griefing attacks.
 			assert_eq!(
@@ -400,7 +400,7 @@ mod tests {
 					max_nonce + 1,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::TooManyUnrewardedRelayers,
+				ReceptionResult::TooManyUnrewardedRelayers,
 			);
 		});
 	}
@@ -417,7 +417,7 @@ mod tests {
 						current_nonce,
 						inbound_message_data(REGULAR_PAYLOAD)
 					),
-					ReceivalResult::Dispatched(dispatch_result(0))
+					ReceptionResult::Dispatched(dispatch_result(0))
 				);
 			}
 			// Fails to dispatch new message from different than latest relayer.
@@ -427,7 +427,7 @@ mod tests {
 					max_nonce + 1,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::TooManyUnconfirmedMessages,
+				ReceptionResult::TooManyUnconfirmedMessages,
 			);
 			// Fails to dispatch new messages from latest relayer.
 			assert_eq!(
@@ -436,7 +436,7 @@ mod tests {
 					max_nonce + 1,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::TooManyUnconfirmedMessages,
+				ReceptionResult::TooManyUnconfirmedMessages,
 			);
 		});
 	}
@@ -451,7 +451,7 @@ mod tests {
 					1,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::Dispatched(dispatch_result(0))
+				ReceptionResult::Dispatched(dispatch_result(0))
 			);
 			assert_eq!(
 				lane.receive_message::<TestMessageDispatch>(
@@ -459,7 +459,7 @@ mod tests {
 					2,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::Dispatched(dispatch_result(0))
+				ReceptionResult::Dispatched(dispatch_result(0))
 			);
 			assert_eq!(
 				lane.receive_message::<TestMessageDispatch>(
@@ -467,7 +467,7 @@ mod tests {
 					3,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::Dispatched(dispatch_result(0))
+				ReceptionResult::Dispatched(dispatch_result(0))
 			);
 			assert_eq!(
 				lane.storage.get_or_init_data().relayers,
@@ -490,7 +490,7 @@ mod tests {
 					1,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::Dispatched(dispatch_result(0))
+				ReceptionResult::Dispatched(dispatch_result(0))
 			);
 			assert_eq!(
 				lane.receive_message::<TestMessageDispatch>(
@@ -498,7 +498,7 @@ mod tests {
 					1,
 					inbound_message_data(REGULAR_PAYLOAD)
 				),
-				ReceivalResult::InvalidNonce,
+				ReceptionResult::InvalidNonce,
 			);
 		});
 	}
@@ -524,7 +524,7 @@ mod tests {
 					1,
 					inbound_message_data(payload)
 				),
-				ReceivalResult::Dispatched(dispatch_result(1))
+				ReceptionResult::Dispatched(dispatch_result(1))
 			);
 		});
 	}
diff --git a/bridges/modules/messages/src/lib.rs b/bridges/modules/messages/src/lib.rs
index a86cb326cf0404512b7fe6ad0aa2a696ff7d0a47..bc00db9eba5ba12dbdaa0de7008f293a727a7ef5 100644
--- a/bridges/modules/messages/src/lib.rs
+++ b/bridges/modules/messages/src/lib.rs
@@ -47,7 +47,7 @@ pub use weights_ext::{
 
 use crate::{
 	inbound_lane::{InboundLane, InboundLaneStorage},
-	outbound_lane::{OutboundLane, OutboundLaneStorage, ReceivalConfirmationError},
+	outbound_lane::{OutboundLane, OutboundLaneStorage, ReceptionConfirmationError},
 };
 
 use bp_messages::{
@@ -90,7 +90,7 @@ pub const LOG_TARGET: &str = "runtime::bridge-messages";
 #[frame_support::pallet]
 pub mod pallet {
 	use super::*;
-	use bp_messages::{ReceivalResult, ReceivedMessages};
+	use bp_messages::{ReceivedMessages, ReceptionResult};
 	use bp_runtime::RangeInclusiveExt;
 	use frame_support::pallet_prelude::*;
 	use frame_system::pallet_prelude::*;
@@ -376,13 +376,13 @@ pub mod pallet {
 					// delivery transaction cost anyway. And base cost covers everything except
 					// dispatch, so we have a balance here.
 					let unspent_weight = match &receival_result {
-						ReceivalResult::Dispatched(dispatch_result) => {
+						ReceptionResult::Dispatched(dispatch_result) => {
 							valid_messages += 1;
 							dispatch_result.unspent_weight
 						},
-						ReceivalResult::InvalidNonce |
-						ReceivalResult::TooManyUnrewardedRelayers |
-						ReceivalResult::TooManyUnconfirmedMessages => message_dispatch_weight,
+						ReceptionResult::InvalidNonce |
+						ReceptionResult::TooManyUnrewardedRelayers |
+						ReceptionResult::TooManyUnconfirmedMessages => message_dispatch_weight,
 					};
 					lane_messages_received_status.push(message.key.nonce, receival_result);
 
@@ -455,7 +455,7 @@ pub mod pallet {
 					last_delivered_nonce,
 					&lane_data.relayers,
 				)
-				.map_err(Error::<T, I>::ReceivalConfirmation)?;
+				.map_err(Error::<T, I>::ReceptionConfirmation)?;
 
 			if let Some(confirmed_messages) = confirmed_messages {
 				// emit 'delivered' event
@@ -563,7 +563,7 @@ pub mod pallet {
 		/// The message someone is trying to work with (i.e. increase fee) is not yet sent.
 		MessageIsNotYetSent,
 		/// Error confirming messages receival.
-		ReceivalConfirmation(ReceivalConfirmationError),
+		ReceptionConfirmation(ReceptionConfirmationError),
 		/// Error generated by the `OwnedBridgeModule` trait.
 		BridgeModule(bp_runtime::OwnedBridgeModuleError),
 	}
@@ -923,7 +923,7 @@ mod tests {
 			PAYLOAD_REJECTED_BY_TARGET_CHAIN, REGULAR_PAYLOAD, TEST_LANE_ID, TEST_LANE_ID_2,
 			TEST_LANE_ID_3, TEST_RELAYER_A, TEST_RELAYER_B,
 		},
-		outbound_lane::ReceivalConfirmationError,
+		outbound_lane::ReceptionConfirmationError,
 	};
 	use bp_messages::{
 		source_chain::MessagesBridge, BridgeMessagesCall, UnrewardedRelayer,
@@ -950,11 +950,11 @@ mod tests {
 
 		let outbound_lane = outbound_lane::<TestRuntime, ()>(lane_id);
 		let message_nonce = outbound_lane.data().latest_generated_nonce + 1;
-		let prev_enqueud_messages = outbound_lane.data().queued_messages().saturating_len();
+		let prev_enqueued_messages = outbound_lane.data().queued_messages().saturating_len();
 		let valid_message = Pallet::<TestRuntime, ()>::validate_message(lane_id, &REGULAR_PAYLOAD)
 			.expect("validate_message has failed");
 		let artifacts = Pallet::<TestRuntime, ()>::send_message(valid_message);
-		assert_eq!(artifacts.enqueued_messages, prev_enqueud_messages + 1);
+		assert_eq!(artifacts.enqueued_messages, prev_enqueued_messages + 1);
 
 		// check event with assigned nonce
 		assert_eq!(
@@ -1541,7 +1541,7 @@ mod tests {
 	}
 
 	#[test]
-	fn actual_dispatch_weight_does_not_overlow() {
+	fn actual_dispatch_weight_does_not_overflow() {
 		run_test(|| {
 			let message1 = message(1, message_payload(0, u64::MAX / 2));
 			let message2 = message(2, message_payload(0, u64::MAX / 2));
@@ -1775,7 +1775,7 @@ mod tests {
 			//    returns `last_confirmed_nonce`;
 			// 3) it means that we're going to confirm delivery of messages 1..=1;
 			// 4) so the number of declared messages (see `UnrewardedRelayersState`) is `0` and
-			//    numer of actually confirmed messages is `1`.
+			//    number of actually confirmed messages is `1`.
 			assert_noop!(
 				Pallet::<TestRuntime>::receive_messages_delivery_proof(
 					RuntimeOrigin::signed(1),
@@ -1785,8 +1785,8 @@ mod tests {
 					))),
 					UnrewardedRelayersState { last_delivered_nonce: 1, ..Default::default() },
 				),
-				Error::<TestRuntime, ()>::ReceivalConfirmation(
-					ReceivalConfirmationError::TryingToConfirmMoreMessagesThanExpected
+				Error::<TestRuntime, ()>::ReceptionConfirmation(
+					ReceptionConfirmationError::TryingToConfirmMoreMessagesThanExpected
 				),
 			);
 		});
diff --git a/bridges/modules/messages/src/outbound_lane.rs b/bridges/modules/messages/src/outbound_lane.rs
index 431c2cfb7eef3e8dd48e49c6ac37153ae64d57b6..acef5546d2a64fa8a3fb38c6b41ae30819cdeaa2 100644
--- a/bridges/modules/messages/src/outbound_lane.rs
+++ b/bridges/modules/messages/src/outbound_lane.rs
@@ -53,7 +53,7 @@ pub type StoredMessagePayload<T, I> = BoundedVec<u8, <T as Config<I>>::MaximalOu
 
 /// Result of messages receival confirmation.
 #[derive(Encode, Decode, RuntimeDebug, PartialEq, Eq, PalletError, TypeInfo)]
-pub enum ReceivalConfirmationError {
+pub enum ReceptionConfirmationError {
 	/// Bridged chain is trying to confirm more messages than we have generated. May be a result
 	/// of invalid bridged chain storage.
 	FailedToConfirmFutureMessages,
@@ -103,7 +103,7 @@ impl<S: OutboundLaneStorage> OutboundLane<S> {
 		max_allowed_messages: MessageNonce,
 		latest_delivered_nonce: MessageNonce,
 		relayers: &VecDeque<UnrewardedRelayer<RelayerId>>,
-	) -> Result<Option<DeliveredMessages>, ReceivalConfirmationError> {
+	) -> Result<Option<DeliveredMessages>, ReceptionConfirmationError> {
 		let mut data = self.storage.data();
 		let confirmed_messages = DeliveredMessages {
 			begin: data.latest_received_nonce.saturating_add(1),
@@ -113,7 +113,7 @@ impl<S: OutboundLaneStorage> OutboundLane<S> {
 			return Ok(None)
 		}
 		if confirmed_messages.end > data.latest_generated_nonce {
-			return Err(ReceivalConfirmationError::FailedToConfirmFutureMessages)
+			return Err(ReceptionConfirmationError::FailedToConfirmFutureMessages)
 		}
 		if confirmed_messages.total_messages() > max_allowed_messages {
 			// that the relayer has declared correct number of messages that the proof contains (it
@@ -127,7 +127,7 @@ impl<S: OutboundLaneStorage> OutboundLane<S> {
 				confirmed_messages.total_messages(),
 				max_allowed_messages,
 			);
-			return Err(ReceivalConfirmationError::TryingToConfirmMoreMessagesThanExpected)
+			return Err(ReceptionConfirmationError::TryingToConfirmMoreMessagesThanExpected)
 		}
 
 		ensure_unrewarded_relayers_are_correct(confirmed_messages.end, relayers)?;
@@ -176,24 +176,24 @@ impl<S: OutboundLaneStorage> OutboundLane<S> {
 fn ensure_unrewarded_relayers_are_correct<RelayerId>(
 	latest_received_nonce: MessageNonce,
 	relayers: &VecDeque<UnrewardedRelayer<RelayerId>>,
-) -> Result<(), ReceivalConfirmationError> {
+) -> Result<(), ReceptionConfirmationError> {
 	let mut expected_entry_begin = relayers.front().map(|entry| entry.messages.begin);
 	for entry in relayers {
 		// unrewarded relayer entry must have at least 1 unconfirmed message
 		// (guaranteed by the `InboundLane::receive_message()`)
 		if entry.messages.end < entry.messages.begin {
-			return Err(ReceivalConfirmationError::EmptyUnrewardedRelayerEntry)
+			return Err(ReceptionConfirmationError::EmptyUnrewardedRelayerEntry)
 		}
 		// every entry must confirm range of messages that follows previous entry range
 		// (guaranteed by the `InboundLane::receive_message()`)
 		if expected_entry_begin != Some(entry.messages.begin) {
-			return Err(ReceivalConfirmationError::NonConsecutiveUnrewardedRelayerEntries)
+			return Err(ReceptionConfirmationError::NonConsecutiveUnrewardedRelayerEntries)
 		}
 		expected_entry_begin = entry.messages.end.checked_add(1);
 		// entry can't confirm messages larger than `inbound_lane_data.latest_received_nonce()`
 		// (guaranteed by the `InboundLane::receive_message()`)
 		if entry.messages.end > latest_received_nonce {
-			return Err(ReceivalConfirmationError::FailedToConfirmFutureMessages)
+			return Err(ReceptionConfirmationError::FailedToConfirmFutureMessages)
 		}
 	}
 
@@ -228,7 +228,7 @@ mod tests {
 	fn assert_3_messages_confirmation_fails(
 		latest_received_nonce: MessageNonce,
 		relayers: &VecDeque<UnrewardedRelayer<TestRelayer>>,
-	) -> Result<Option<DeliveredMessages>, ReceivalConfirmationError> {
+	) -> Result<Option<DeliveredMessages>, ReceptionConfirmationError> {
 		run_test(|| {
 			let mut lane = outbound_lane::<TestRuntime, _>(TEST_LANE_ID);
 			lane.send_message(outbound_message_data(REGULAR_PAYLOAD));
@@ -299,7 +299,7 @@ mod tests {
 	fn confirm_delivery_rejects_nonce_larger_than_last_generated() {
 		assert_eq!(
 			assert_3_messages_confirmation_fails(10, &unrewarded_relayers(1..=10),),
-			Err(ReceivalConfirmationError::FailedToConfirmFutureMessages),
+			Err(ReceptionConfirmationError::FailedToConfirmFutureMessages),
 		);
 	}
 
@@ -314,7 +314,7 @@ mod tests {
 					.chain(unrewarded_relayers(3..=3).into_iter())
 					.collect(),
 			),
-			Err(ReceivalConfirmationError::FailedToConfirmFutureMessages),
+			Err(ReceptionConfirmationError::FailedToConfirmFutureMessages),
 		);
 	}
 
@@ -330,7 +330,7 @@ mod tests {
 					.chain(unrewarded_relayers(2..=3).into_iter())
 					.collect(),
 			),
-			Err(ReceivalConfirmationError::EmptyUnrewardedRelayerEntry),
+			Err(ReceptionConfirmationError::EmptyUnrewardedRelayerEntry),
 		);
 	}
 
@@ -345,7 +345,7 @@ mod tests {
 					.chain(unrewarded_relayers(2..=2).into_iter())
 					.collect(),
 			),
-			Err(ReceivalConfirmationError::NonConsecutiveUnrewardedRelayerEntries),
+			Err(ReceptionConfirmationError::NonConsecutiveUnrewardedRelayerEntries),
 		);
 	}
 
@@ -409,11 +409,11 @@ mod tests {
 			lane.send_message(outbound_message_data(REGULAR_PAYLOAD));
 			assert_eq!(
 				lane.confirm_delivery(0, 3, &unrewarded_relayers(1..=3)),
-				Err(ReceivalConfirmationError::TryingToConfirmMoreMessagesThanExpected),
+				Err(ReceptionConfirmationError::TryingToConfirmMoreMessagesThanExpected),
 			);
 			assert_eq!(
 				lane.confirm_delivery(2, 3, &unrewarded_relayers(1..=3)),
-				Err(ReceivalConfirmationError::TryingToConfirmMoreMessagesThanExpected),
+				Err(ReceptionConfirmationError::TryingToConfirmMoreMessagesThanExpected),
 			);
 			assert_eq!(
 				lane.confirm_delivery(3, 3, &unrewarded_relayers(1..=3)),
diff --git a/bridges/modules/parachains/src/mock.rs b/bridges/modules/parachains/src/mock.rs
index 3af3fd3e76398eaefdb7a9380344371ec44d27d7..d9cbabf850ec99ee13baa0f8bfc013b1192bd000 100644
--- a/bridges/modules/parachains/src/mock.rs
+++ b/bridges/modules/parachains/src/mock.rs
@@ -261,7 +261,7 @@ impl Chain for TestBridgedChain {
 impl ChainWithGrandpa for TestBridgedChain {
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = "";
 	const MAX_AUTHORITIES_COUNT: u32 = 16;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 = 8;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 = 8;
 	const MAX_MANDATORY_HEADER_SIZE: u32 = 256;
 	const AVERAGE_HEADER_SIZE: u32 = 64;
 }
@@ -294,7 +294,7 @@ impl Chain for OtherBridgedChain {
 impl ChainWithGrandpa for OtherBridgedChain {
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = "";
 	const MAX_AUTHORITIES_COUNT: u32 = 16;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 = 8;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 = 8;
 	const MAX_MANDATORY_HEADER_SIZE: u32 = 256;
 	const AVERAGE_HEADER_SIZE: u32 = 64;
 }
diff --git a/bridges/modules/xcm-bridge-hub-router/src/lib.rs b/bridges/modules/xcm-bridge-hub-router/src/lib.rs
index f219be78f9e1b5469fb752eed3f662c954d0ec42..5d0be41b1b5588e3ddc8c6306c9bf83ec29d6056 100644
--- a/bridges/modules/xcm-bridge-hub-router/src/lib.rs
+++ b/bridges/modules/xcm-bridge-hub-router/src/lib.rs
@@ -427,7 +427,7 @@ mod tests {
 		run_test(|| {
 			Bridge::<TestRuntime, ()>::put(uncongested_bridge(FixedU128::from_rational(125, 100)));
 
-			// it shold eventually decreased to one
+			// it should eventually decreased to one
 			while XcmBridgeHubRouter::bridge().delivery_fee_factor > MINIMAL_DELIVERY_FEE_FACTOR {
 				XcmBridgeHubRouter::on_initialize(One::one());
 			}
diff --git a/bridges/modules/xcm-bridge-hub/Cargo.toml b/bridges/modules/xcm-bridge-hub/Cargo.toml
index 4d5d012345a4ca54fa04c30799767c11aeb10caf..1200af48345b548acc74709b28099f3344c36a85 100644
--- a/bridges/modules/xcm-bridge-hub/Cargo.toml
+++ b/bridges/modules/xcm-bridge-hub/Cargo.toml
@@ -1,6 +1,6 @@
 [package]
 name = "pallet-xcm-bridge-hub"
-description = "Module that adds dynamic bridges/lanes support to XCM infrastucture at the bridge hub."
+description = "Module that adds dynamic bridges/lanes support to XCM infrastructure at the bridge hub."
 version = "0.2.0"
 authors.workspace = true
 edition.workspace = true
diff --git a/bridges/primitives/header-chain/src/justification/mod.rs b/bridges/primitives/header-chain/src/justification/mod.rs
index b32d8bdb5f1d8ce05722c938a083d7f582139835..d7c2cbf429e2b01efe4a9ea2481e66e2857d0044 100644
--- a/bridges/primitives/header-chain/src/justification/mod.rs
+++ b/bridges/primitives/header-chain/src/justification/mod.rs
@@ -83,7 +83,7 @@ impl<H: HeaderT> GrandpaJustification<H> {
 			.saturating_add(HashOf::<C>::max_encoded_len().saturated_into());
 
 		let max_expected_votes_ancestries_size =
-			C::REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY.saturating_mul(C::AVERAGE_HEADER_SIZE);
+			C::REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY.saturating_mul(C::AVERAGE_HEADER_SIZE);
 
 		// justification is round number (u64=8b), a signed GRANDPA commit and the
 		// `votes_ancestries` vector
diff --git a/bridges/primitives/header-chain/src/justification/verification/mod.rs b/bridges/primitives/header-chain/src/justification/verification/mod.rs
index c71149bf9c28e350fb43429623ca47cd367b9091..9df3511e1035ef769e5ef6c373253161be041efb 100644
--- a/bridges/primitives/header-chain/src/justification/verification/mod.rs
+++ b/bridges/primitives/header-chain/src/justification/verification/mod.rs
@@ -318,7 +318,7 @@ trait JustificationVerifier<Header: HeaderT> {
 		}
 
 		// check that the cumulative weight of validators that voted for the justification target
-		// (or one of its descendents) is larger than the required threshold.
+		// (or one of its descendants) is larger than the required threshold.
 		if cumulative_weight < threshold {
 			return Err(Error::TooLowCumulativeWeight)
 		}
diff --git a/bridges/primitives/header-chain/src/lib.rs b/bridges/primitives/header-chain/src/lib.rs
index 84a6a881a835b8afc3b5cde8992df1733859d29a..98fb9ff83d8335fc04fbce7f9e566c73d15752a8 100644
--- a/bridges/primitives/header-chain/src/lib.rs
+++ b/bridges/primitives/header-chain/src/lib.rs
@@ -283,7 +283,7 @@ pub trait ChainWithGrandpa: Chain {
 	/// ancestry and the pallet will accept such justification. The limit is only used to compute
 	/// maximal refund amount and submitting justifications which exceed the limit, may be costly
 	/// to submitter.
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32;
 
 	/// Maximal size of the mandatory chain header. Mandatory header is the header that enacts new
 	/// GRANDPA authorities set (so it has large digest inside).
@@ -317,8 +317,8 @@ where
 	const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str =
 		<T::Chain as ChainWithGrandpa>::WITH_CHAIN_GRANDPA_PALLET_NAME;
 	const MAX_AUTHORITIES_COUNT: u32 = <T::Chain as ChainWithGrandpa>::MAX_AUTHORITIES_COUNT;
-	const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 =
-		<T::Chain as ChainWithGrandpa>::REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY;
+	const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 =
+		<T::Chain as ChainWithGrandpa>::REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY;
 	const MAX_MANDATORY_HEADER_SIZE: u32 =
 		<T::Chain as ChainWithGrandpa>::MAX_MANDATORY_HEADER_SIZE;
 	const AVERAGE_HEADER_SIZE: u32 = <T::Chain as ChainWithGrandpa>::AVERAGE_HEADER_SIZE;
@@ -373,7 +373,7 @@ mod tests {
 	impl ChainWithGrandpa for TestChain {
 		const WITH_CHAIN_GRANDPA_PALLET_NAME: &'static str = "Test";
 		const MAX_AUTHORITIES_COUNT: u32 = 128;
-		const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 = 2;
+		const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 = 2;
 		const MAX_MANDATORY_HEADER_SIZE: u32 = 100_000;
 		const AVERAGE_HEADER_SIZE: u32 = 1_024;
 	}
diff --git a/bridges/primitives/messages/src/lib.rs b/bridges/primitives/messages/src/lib.rs
index 51b3f25f7151867b52e8e5f49bc70b0a3632c05e..c3f79b3ee388c4584def56056f6cdf6328032e18 100644
--- a/bridges/primitives/messages/src/lib.rs
+++ b/bridges/primitives/messages/src/lib.rs
@@ -289,27 +289,27 @@ pub struct ReceivedMessages<DispatchLevelResult> {
 	/// Id of the lane which is receiving messages.
 	pub lane: LaneId,
 	/// Result of messages which we tried to dispatch
-	pub receive_results: Vec<(MessageNonce, ReceivalResult<DispatchLevelResult>)>,
+	pub receive_results: Vec<(MessageNonce, ReceptionResult<DispatchLevelResult>)>,
 }
 
 impl<DispatchLevelResult> ReceivedMessages<DispatchLevelResult> {
 	/// Creates new `ReceivedMessages` structure from given results.
 	pub fn new(
 		lane: LaneId,
-		receive_results: Vec<(MessageNonce, ReceivalResult<DispatchLevelResult>)>,
+		receive_results: Vec<(MessageNonce, ReceptionResult<DispatchLevelResult>)>,
 	) -> Self {
 		ReceivedMessages { lane, receive_results }
 	}
 
 	/// Push `result` of the `message` delivery onto `receive_results` vector.
-	pub fn push(&mut self, message: MessageNonce, result: ReceivalResult<DispatchLevelResult>) {
+	pub fn push(&mut self, message: MessageNonce, result: ReceptionResult<DispatchLevelResult>) {
 		self.receive_results.push((message, result));
 	}
 }
 
 /// Result of single message receival.
 #[derive(RuntimeDebug, Encode, Decode, PartialEq, Eq, Clone, TypeInfo)]
-pub enum ReceivalResult<DispatchLevelResult> {
+pub enum ReceptionResult<DispatchLevelResult> {
 	/// Message has been received and dispatched. Note that we don't care whether dispatch has
 	/// been successful or not - in both case message falls into this category.
 	///
diff --git a/bridges/primitives/polkadot-core/src/lib.rs b/bridges/primitives/polkadot-core/src/lib.rs
index df2836495bbe131e9cf810c43eb4af5eefaf43b7..e83be59b23890036905ae1abb441c454c2ce29a5 100644
--- a/bridges/primitives/polkadot-core/src/lib.rs
+++ b/bridges/primitives/polkadot-core/src/lib.rs
@@ -71,7 +71,7 @@ pub const MAX_AUTHORITIES_COUNT: u32 = 1_256;
 /// justifications with any additional headers in votes ancestry, so reasonable headers may
 /// be set to zero. But we assume that there may be small GRANDPA lags, so we're leaving some
 /// reserve here.
-pub const REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY: u32 = 2;
+pub const REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY: u32 = 2;
 
 /// Average header size in `votes_ancestries` field of justification on Polkadot-like
 /// chains.
diff --git a/bridges/primitives/runtime/src/chain.rs b/bridges/primitives/runtime/src/chain.rs
index 9ba21a1cddf13896b21494045cea7fdd92259ce8..4ec5a001a99ecad21617ed0afc57d3edac383d0d 100644
--- a/bridges/primitives/runtime/src/chain.rs
+++ b/bridges/primitives/runtime/src/chain.rs
@@ -104,7 +104,7 @@ pub trait Chain: Send + Sync + 'static {
 	const ID: ChainId;
 
 	/// A type that fulfills the abstract idea of what a Substrate block number is.
-	// Constraits come from the associated Number type of `sp_runtime::traits::Header`
+	// Constraints come from the associated Number type of `sp_runtime::traits::Header`
 	// See here for more info:
 	// https://crates.parity.io/sp_runtime/traits/trait.Header.html#associatedtype.Number
 	//
@@ -125,7 +125,7 @@ pub trait Chain: Send + Sync + 'static {
 		+ MaxEncodedLen;
 
 	/// A type that fulfills the abstract idea of what a Substrate hash is.
-	// Constraits come from the associated Hash type of `sp_runtime::traits::Header`
+	// Constraints come from the associated Hash type of `sp_runtime::traits::Header`
 	// See here for more info:
 	// https://crates.parity.io/sp_runtime/traits/trait.Header.html#associatedtype.Hash
 	type Hash: Parameter
@@ -143,7 +143,7 @@ pub trait Chain: Send + Sync + 'static {
 
 	/// A type that fulfills the abstract idea of what a Substrate hasher (a type
 	/// that produces hashes) is.
-	// Constraits come from the associated Hashing type of `sp_runtime::traits::Header`
+	// Constraints come from the associated Hashing type of `sp_runtime::traits::Header`
 	// See here for more info:
 	// https://crates.parity.io/sp_runtime/traits/trait.Header.html#associatedtype.Hashing
 	type Hasher: HashT<Output = Self::Hash>;
diff --git a/bridges/primitives/runtime/src/lib.rs b/bridges/primitives/runtime/src/lib.rs
index 850318923dc7671c26cc3edcf2f9d59bd7b987b9..c9c5c9412913b0470024e9e1473e5d69ff184f25 100644
--- a/bridges/primitives/runtime/src/lib.rs
+++ b/bridges/primitives/runtime/src/lib.rs
@@ -56,7 +56,7 @@ mod chain;
 mod storage_proof;
 mod storage_types;
 
-// Re-export macro to aviod include paste dependency everywhere
+// Re-export macro to avoid include paste dependency everywhere
 pub use sp_runtime::paste;
 
 /// Use this when something must be shared among all instances.
@@ -461,7 +461,7 @@ macro_rules! generate_static_str_provider {
 	};
 }
 
-/// Error message that is only dispayable in `std` environment.
+/// Error message that is only displayable in `std` environment.
 #[derive(Encode, Decode, Clone, Eq, PartialEq, PalletError, TypeInfo)]
 #[scale_info(skip_type_params(T))]
 pub struct StrippableError<T> {
diff --git a/bridges/primitives/test-utils/src/lib.rs b/bridges/primitives/test-utils/src/lib.rs
index 1d80890779bf8310b393d585749e96f9577196a1..f4fe4a242e79c0e1c8a499c4dd18ed4a2164c656 100644
--- a/bridges/primitives/test-utils/src/lib.rs
+++ b/bridges/primitives/test-utils/src/lib.rs
@@ -88,7 +88,7 @@ pub fn make_default_justification<H: HeaderT>(header: &H) -> GrandpaJustificatio
 /// Generate justifications in a way where we are able to tune the number of pre-commits
 /// and vote ancestries which are included in the justification.
 ///
-/// This is useful for benchmarkings where we want to generate valid justifications with
+/// This is useful for benchmarks where we want to generate valid justifications with
 /// a specific number of pre-commits (tuned with the number of "authorities") and/or a specific
 /// number of vote ancestries (tuned with the "votes" parameter).
 ///
diff --git a/bridges/testing/environments/rococo-westend/rococo.zndsl b/bridges/testing/environments/rococo-westend/rococo.zndsl
index 5b49c7c632fa4dd0ce77134858a2f697acbfff16..a75286445a240eb302ac8fd23ae7fe707e6c0af3 100644
--- a/bridges/testing/environments/rococo-westend/rococo.zndsl
+++ b/bridges/testing/environments/rococo-westend/rococo.zndsl
@@ -1,7 +1,7 @@
-Description: Check if the with-Westend GRANPDA pallet was initialized at Rococo BH
+Description: Check if the with-Westend GRANDPA pallet was initialized at Rococo BH
 Network: ./bridge_hub_rococo_local_network.toml
 Creds: config
 
-# relay is already started - let's wait until with-Westend GRANPDA pallet is initialized at Rococo
+# relay is already started - let's wait until with-Westend GRANDPA pallet is initialized at Rococo
 bridge-hub-rococo-collator1: js-script {{FRAMEWORK_PATH}}/js-helpers/best-finalized-header-at-bridged-chain.js with "Westend,0" within 400 seconds
 
diff --git a/bridges/testing/environments/rococo-westend/westend.zndsl b/bridges/testing/environments/rococo-westend/westend.zndsl
index 07968838852f7c0a00131db3080c460c07d08206..21d4ebf3b05b003083f7d35bf6bb7a1ca4c1ad05 100644
--- a/bridges/testing/environments/rococo-westend/westend.zndsl
+++ b/bridges/testing/environments/rococo-westend/westend.zndsl
@@ -1,6 +1,6 @@
-Description: Check if the with-Rococo GRANPDA pallet was initialized at Westend BH
+Description: Check if the with-Rococo GRANDPA pallet was initialized at Westend BH
 Network: ./bridge_hub_westend_local_network.toml
 Creds: config
 
-# relay is already started - let's wait until with-Rococo GRANPDA pallet is initialized at Westend
+# relay is already started - let's wait until with-Rococo GRANDPA pallet is initialized at Westend
 bridge-hub-westend-collator1: js-script {{FRAMEWORK_PATH}}/js-helpers/best-finalized-header-at-bridged-chain.js with "Rococo,0" within 400 seconds
diff --git a/bridges/testing/framework/utils/generate_hex_encoded_call/index.js b/bridges/testing/framework/utils/generate_hex_encoded_call/index.js
index 30f89d754ceb7de1b24bc31413e09c862a461256..c8e361b25a9ce3e56f3c839d53e2fc67106a98c8 100644
--- a/bridges/testing/framework/utils/generate_hex_encoded_call/index.js
+++ b/bridges/testing/framework/utils/generate_hex_encoded_call/index.js
@@ -126,36 +126,36 @@ if (!process.argv[2] || !process.argv[3]) {
 }
 
 const type = process.argv[2];
-const rpcEnpoint = process.argv[3];
+const rpcEndpoint = process.argv[3];
 const output = process.argv[4];
 const inputArgs = process.argv.slice(5, process.argv.length);
 console.log(`Generating hex-encoded call data for:`);
 console.log(`	type: ${type}`);
-console.log(`	rpcEnpoint: ${rpcEnpoint}`);
+console.log(`	rpcEndpoint: ${rpcEndpoint}`);
 console.log(`	output: ${output}`);
 console.log(`	inputArgs: ${inputArgs}`);
 
 switch (type) {
 	case 'remark-with-event':
-		remarkWithEvent(rpcEnpoint, output);
+		remarkWithEvent(rpcEndpoint, output);
 		break;
 	case 'add-exporter-config':
-		addExporterConfig(rpcEnpoint, output, inputArgs[0], inputArgs[1]);
+		addExporterConfig(rpcEndpoint, output, inputArgs[0], inputArgs[1]);
 		break;
 	case 'remove-exporter-config':
-		removeExporterConfig(rpcEnpoint, output, inputArgs[0], inputArgs[1]);
+		removeExporterConfig(rpcEndpoint, output, inputArgs[0], inputArgs[1]);
 		break;
 	case 'add-universal-alias':
-		addUniversalAlias(rpcEnpoint, output, inputArgs[0], inputArgs[1]);
+		addUniversalAlias(rpcEndpoint, output, inputArgs[0], inputArgs[1]);
 		break;
 	case 'add-reserve-location':
-		addReserveLocation(rpcEnpoint, output, inputArgs[0]);
+		addReserveLocation(rpcEndpoint, output, inputArgs[0]);
 		break;
 	case 'force-create-asset':
-		forceCreateAsset(rpcEnpoint, output, inputArgs[0], inputArgs[1], inputArgs[2], inputArgs[3]);
+		forceCreateAsset(rpcEndpoint, output, inputArgs[0], inputArgs[1], inputArgs[2], inputArgs[3]);
 		break;
 	case 'force-xcm-version':
-		forceXcmVersion(rpcEnpoint, output, inputArgs[0], inputArgs[1]);
+		forceXcmVersion(rpcEndpoint, output, inputArgs[0], inputArgs[1]);
 		break;
 	case 'check':
 		console.log(`Checking nodejs installation, if you see this everything is ready!`);
diff --git a/bridges/testing/run-tests.sh b/bridges/testing/run-tests.sh
index 6149d9912653c79968a0229759c8f1bf46f68a9f..fd12b57f53349a0a449af7103c05341d3c94ceb9 100755
--- a/bridges/testing/run-tests.sh
+++ b/bridges/testing/run-tests.sh
@@ -30,7 +30,7 @@ done
 export POLKADOT_SDK_PATH=`realpath $(dirname "$0")/../..`
 export BRIDGE_TESTS_FOLDER=$POLKADOT_SDK_PATH/bridges/testing/tests
 
-# set pathc to binaries
+# set path to binaries
 if [ "$ZOMBIENET_DOCKER_PATHS" -eq 1 ]; then
     export POLKADOT_BINARY=/usr/local/bin/polkadot
     export POLKADOT_PARACHAIN_BINARY=/usr/local/bin/polkadot-parachain
diff --git a/bridges/testing/tests/0002-mandatory-headers-synced-while-idle/run.sh b/bridges/testing/tests/0002-mandatory-headers-synced-while-idle/run.sh
index 7d5b8d9273664b0861e8ffe1c528e9e1718c4df4..3a604b3876d96241903c1c5a110cc6392f26cb7e 100755
--- a/bridges/testing/tests/0002-mandatory-headers-synced-while-idle/run.sh
+++ b/bridges/testing/tests/0002-mandatory-headers-synced-while-idle/run.sh
@@ -24,7 +24,7 @@ echo -e "Sleeping 90s before starting relayer ...\n"
 sleep 90
 ${BASH_SOURCE%/*}/../../environments/rococo-westend/start_relayer.sh $rococo_dir $westend_dir relayer_pid
 
-# Sometimes the relayer syncs multiple parachain heads in the begining leading to test failures.
+# Sometimes the relayer syncs multiple parachain heads in the beginning leading to test failures.
 # See issue: https://github.com/paritytech/parity-bridges-common/issues/2838.
 # TODO: Remove this sleep after the issue is fixed.
 echo -e "Sleeping 180s before runing the tests ...\n"
diff --git a/bridges/modules/grandpa/src/call_ext.rs b/bridges/modules/grandpa/src/call_ext.rs
index e3c778b480baa51a8b9e5d04564ac54bc7a68a21..4a7ebb3cc8d42d7cb9d97d5c6990bb33658416bd 100644
--- a/bridges/modules/grandpa/src/call_ext.rs
+++ b/bridges/modules/grandpa/src/call_ext.rs
@@ -205,7 +205,7 @@ pub(crate) fn submit_finality_proof_info_from_args<T: Config<I>, I: 'static>(
 	// as an extra weight.
 	let votes_ancestries_len = justification.votes_ancestries.len().saturated_into();
 	let extra_weight =
-		if votes_ancestries_len > T::BridgedChain::REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY {
+		if votes_ancestries_len > T::BridgedChain::REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY {
 			T::WeightInfo::submit_finality_proof(precommits_len, votes_ancestries_len)
 		} else {
 			Weight::zero()
@@ -396,11 +396,11 @@ mod tests {
 		let finality_target = test_header(1);
 		let mut justification_params = JustificationGeneratorParams {
 			header: finality_target.clone(),
-			ancestors: TestBridgedChain::REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY,
+			ancestors: TestBridgedChain::REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY,
 			..Default::default()
 		};
 
 		// when there are `REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY` headers => no refund
 		let justification = make_justification_for_header(justification_params.clone());
 		let call = RuntimeCall::Grandpa(crate::Call::submit_finality_proof_ex {
 			finality_target: Box::new(finality_target.clone()),
@@ -409,7 +409,7 @@ mod tests {
 		});
 		assert_eq!(call.submit_finality_proof_info().unwrap().extra_weight, Weight::zero());
 
 		// when there are `REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY + 1` headers => full refund
 		justification_params.ancestors += 1;
 		let justification = make_justification_for_header(justification_params);
 		let call_weight = <TestRuntime as Config>::WeightInfo::submit_finality_proof(
@@ -396,11 +396,11 @@ mod tests {
 		};
 
-		// when there are `REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY` headers => no refund
+		// when there are `REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY` headers => no refund
 		let justification = make_justification_for_header(justification_params.clone());
 		let call = RuntimeCall::Grandpa(crate::Call::submit_finality_proof_ex {
@@ -409,7 +409,7 @@ mod tests {
 		assert_eq!(call.submit_finality_proof_info().unwrap().extra_weight, Weight::zero());
 
-		// when there are `REASONABLE_HEADERS_IN_JUSTIFICATON_ANCESTRY + 1` headers => full refund
+		// when there are `REASONABLE_HEADERS_IN_JUSTIFICATION_ANCESTRY + 1` headers => full refund
 		justification_params.ancestors += 1;
 		let justification = make_justification_for_header(justification_params);